@@ -23,17 +23,18 @@
 
 namespace kt
 {
-template <class Container, class Item>
-struct IndexOfCompare {
-    IndexOfCompare(Container* container) : container(container)
-    {}
+template<class Container, class Item> struct IndexOfCompare {
+    IndexOfCompare(Container *container)
+        : container(container)
+    {
+    }
 
-    bool operator()(Item* a, Item* b)
+    bool operator()(Item *a, Item *b)
     {
         return container->indexOf(a) < container->indexOf(b);
     }
 
-    Container* container;
+    Container *container;
 };
 }
 
