@@ -23,7 +23,8 @@
 
 namespace kt
 {
-IWPrefPage::IWPrefPage(QWidget* parent) : PrefPageInterface(InfoWidgetPluginSettings::self(), i18n("Info Widget"), QStringLiteral("ktip"), parent)
+IWPrefPage::IWPrefPage(QWidget *parent)
+    : PrefPageInterface(InfoWidgetPluginSettings::self(), i18n("Info Widget"), QStringLiteral("ktip"), parent)
 {
     setupUi(this);
 }
