@@ -38,12 +38,12 @@ class MediaFileStream : public Phonon::AbstractMediaStream
 {
     Q_OBJECT
 public:
-    MediaFileStream(bt::TorrentFileStream::WPtr stream, QObject* parent = 0);
+    MediaFileStream(bt::TorrentFileStream::WPtr stream, QObject *parent = 0);
     ~MediaFileStream() override;
 
     enum StreamState {
         PLAYING,
-        BUFFERING
+        BUFFERING,
     };
 
     StreamState state() const
