@@ -43,17 +43,15 @@ struct SeasonEpisodeItem {
 
     SeasonEpisodeItem();
     SeasonEpisodeItem(int s, int e);
-    SeasonEpisodeItem(const SeasonEpisodeItem& item);
+    SeasonEpisodeItem(const SeasonEpisodeItem &item);
 
-    bool operator == (const SeasonEpisodeItem& item) const;
-    SeasonEpisodeItem& operator = (const SeasonEpisodeItem& item);
+    bool operator==(const SeasonEpisodeItem &item) const;
+    SeasonEpisodeItem &operator=(const SeasonEpisodeItem &item);
 };
 
-
 /// Convert a syndication error into an error string
 QString SyndicationErrorString(Syndication::ErrorCode err);
 
-
 /**
     Class to keep track of a feed.
 */
@@ -61,20 +59,23 @@ class Feed : public QObject
 {
     Q_OBJECT
 public:
-    Feed(const QString& dir);
-    Feed(const QString& feed_url, const QString& dir);
-    Feed(const QString& feed_url, Syndication::FeedPtr feed, const QString& dir);
+    Feed(const QString &dir);
+    Feed(const QString &feed_url, const QString &dir);
+    Feed(const QString &feed_url, Syndication::FeedPtr feed, const QString &dir);
     ~Feed();
 
     enum Status {
-        UNLOADED, OK, FAILED_TO_DOWNLOAD, DOWNLOADING
+        UNLOADED,
+        OK,
+        FAILED_TO_DOWNLOAD,
+        DOWNLOADING,
     };
 
     /// Get the display name of the feed
     QString displayName() const;
 
     /// Set the display name
-    void setDisplayName(const QString& dname);
+    void setDisplayName(const QString &dname);
 
     /// Get the libsyndication feed
     Syndication::FeedPtr feedData()
@@ -89,13 +90,13 @@ public:
     }
 
     /// Get the authentication cookie
-    const QString& authenticationCookie() const
+    const QString &authenticationCookie() const
     {
         return cookie;
     }
 
     /// Set the authentication cookie
-    void setAuthenticationCookie(const QString& nc)
+    void setAuthenticationCookie(const QString &nc)
     {
         cookie = nc;
     }
@@ -110,7 +111,7 @@ public:
     void save();
 
     /// Load the feed from it's directory
-    void load(FilterList* filter_list);
+    void load(FilterList *filter_list);
 
     /// Get the feed's data directory
     QString directory() const
@@ -134,19 +135,19 @@ public:
     }
 
     /// Create a new feed directory
-    static QString newFeedDir(const QString& base);
+    static QString newFeedDir(const QString &base);
 
     /// Add a filter to the feed
-    void addFilter(Filter* f);
+    void addFilter(Filter *f);
 
     /// Remove a filter from the feed
-    void removeFilter(Filter* f);
+    void removeFilter(Filter *f);
 
     /// Run filters on the feed
     void runFilters();
 
     /// See if the feed is using a filter
-    bool usingFilter(Filter* f) const
+    bool usingFilter(Filter *f) const
     {
         return filters.contains(f);
     }
@@ -155,7 +156,7 @@ public:
     void clearFilters();
 
     /// Download an item from the feed
-    void downloadItem(Syndication::ItemPtr item, const QString& group, const QString& location, const QString& move_on_completion, bool silently);
+    void downloadItem(Syndication::ItemPtr item, const QString &group, const QString &location, const QString &move_on_completion, bool silently);
 
     /// Check if an item is downloaded
     bool downloaded(Syndication::ItemPtr item) const;
@@ -180,27 +181,27 @@ public:
 
 Q_SIGNALS:
     /// Emitted when a link must de downloaded
-    void downloadLink(const QUrl& link, const QString& group, const QString& location, const QString& move_on_completion, bool silently);
+    void downloadLink(const QUrl &link, const QString &group, const QString &location, const QString &move_on_completion, bool silently);
 
     /// A feed has been renamed
-    void feedRenamed(Feed* f);
+    void feedRenamed(Feed *f);
 
 public:
     /// Update the feed
     void refresh();
 
 private Q_SLOTS:
-    void loadingComplete(Syndication::Loader* loader, Syndication::FeedPtr feed, Syndication::ErrorCode status);
-    void loadingFromDiskComplete(Syndication::Loader* loader, Syndication::FeedPtr feed, Syndication::ErrorCode status);
+    void loadingComplete(Syndication::Loader *loader, Syndication::FeedPtr feed, Syndication::ErrorCode status);
+    void loadingFromDiskComplete(Syndication::Loader *loader, Syndication::FeedPtr feed, Syndication::ErrorCode status);
 
 Q_SIGNALS:
     void updated();
 
 private:
-    bool needToDownload(Syndication::ItemPtr item, Filter* filter);
+    bool needToDownload(Syndication::ItemPtr item, Filter *filter);
     void checkLoaded();
     void loadFromDisk();
-    void parseUrl(const QString& feed_url);
+    void parseUrl(const QString &feed_url);
 
 private:
     QUrl url;
@@ -209,9 +210,9 @@ private:
     QString dir;
     QTimer update_timer;
     Status status;
-    QList<Filter*> filters;
+    QList<Filter *> filters;
     QSet<QString> loaded;
-    QMap<Filter*, QList<SeasonEpisodeItem> > downloaded_se_items;
+    QMap<Filter *, QList<SeasonEpisodeItem>> downloaded_se_items;
     QString custom_name;
     bt::Uint32 refresh_rate;
     QString cookie;
@@ -221,4 +222,3 @@ private:
 }
 
 #endif
-
